// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.wpilibj.shuffleboard.BuiltInWidgets;
import edu.wpi.first.wpilibj.shuffleboard.Shuffleboard;
import edu.wpi.first.wpilibj.shuffleboard.ShuffleboardTab;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.Constants.OIConstants;
import frc.robot.Subsystems.Drivetrain;
import frc.robot.Subsystems.Flipper;
import frc.robot.Subsystems.Shooter;

public class RobotContainer {
  
  //creates instanced variables//
  private Drivetrain drivetrain;
  private Flipper flipper;
  private Shooter shooter;

  private CommandXboxController driver;

  //creates instances of all our subsystems and controllers. also fires our configuration methods//
  public RobotContainer() {
    drivetrain = new Drivetrain();
    flipper = new Flipper();
    shooter = new Shooter();

    driver = new CommandXboxController(OIConstants.kDriverUSB);

    configureBindings();
    configureShuffleboard();
  }

  //runs our autonomous command//
  public Command getAutonomousCommand() {
    return drivetrain.driveTank(() -> .5, () -> .5).withTimeout(2)
    .andThen(shooter.runShooter()).withTimeout(1)
    .andThen(shooter.runShooter()
    .alongWith(flipper.runFlipper()).withTimeout(3));
  }

  //sets up the default commands for each subsystem//
  private void configureBindings() {
    drivetrain.setDefaultCommand(
      drivetrain.driveArcade(
        driver::getLeftY, 
        driver::getLeftX
      )
    );

    flipper.setDefaultCommand(flipper.stopFlipper());
    shooter.setDefaultCommand(shooter.stopShooter());

    //configures our controller to run commands when their respective trigger is activated//
    driver.a().whileTrue(flipper.runFlipper());
    driver.rightBumper().whileTrue(shooter.runShooter());
  }

  //creates tabs and transforms them on the shuffleboard//
  private void configureShuffleboard() {
    ShuffleboardTab robotIndicatorTab = Shuffleboard.getTab(OIConstants.kSensorsTab);

    robotIndicatorTab.addBoolean("Frisbee Loaded?", flipper::getPhotoSwitch1)
    .withPosition(0, 0)
    .withSize(2, 1)
    .withWidget(BuiltInWidgets.kBooleanBox);
  }
}
